#!/bin/sh

# runvdr: Loads the DVB driver and runs VDR
#
# If VDR exits abnormally, the driver will be reloaded
# and VDR restarted.
#
# Set the environment variable VDRUSR to the user id you
# want VDR to run with. If VDRUSR is not set, VDR will run
# as 'root', which is not necessarily advisable.
#
# Since this script loads the DVB driver, it must be started
# as user 'root'.
#
# Any command line parameters will be passed on to the
# actual 'vdr' program.
#

if [ -f /var/lock/stopvdr ] ; then
   exit 1
fi
set x

VDRLOCALE="fi_FI.UTF-8"
export LANG=${VDRLOCALE}
export LC_TIME=${VDRLOCALE}
export LC_MESSAGES=${VDRLOCALE}
export LC_NUMERIC=C

export MNTPATH="/mnt"
export VDRPATH="$MNTPATH/bin"
export VDRLIBPATH="$MNTPATH/lib"
export CNFPATH="$MNTPATH/etc"
export BINPATH="$MNTPATH/bin"
export PLGCNFPATH="$CNFPATH/plugins"
export VDRPRG="$VDRPATH/vdr"
export VDRVIDEO="/video"
export VDRLOCALEPATH="$CNFPATH/locale"

VDRCMD="$VDRPRG -c $CNFPATH -L $VDRLIBPATH -v $VDRVIDEO --lirc=/dev/lircd --localedir=$VDRLOCALEPATH --no-kbd "

while (true) do

   dummyapplication getappid || ( dummyapplication register /usr/bin/dummyapplication; dummyapplication start; sleep 2 )


# Selected plugins
#$VDRCMD -Ptext2skin -P"skinsoppalusikka -l $PLGCNFPATH/skinsoppalusikka" -Pstreamdev-client -Psvdrpservice -Pepgsync -Pepgsearch -Posdteletext -Pfemon -Ppin -Pelvis -Pscalevideo -Pvip1710

# ALL PLUGINS
$VDRCMD -Ptext2skin -P"skinsoppalusikka -l $PLGCNFPATH/skinsoppalusikka" -Pstreamdev-client -Psvdrpservice -Pepgsync -Pepgsearch -Posdteletext -Pfemon -Ppin -Pelvis -Pconflictcheckonly -Pepgsearchonly -Pneutrinoepg -Pquickepgsearch -Premoteosd -Premotetimers -Pstreamdev-server -Psvdrposd -Pttxtsubs -Pvip1710


   date
   sleep 2
   echo "restarting VDR"
   if [ -f /var/lock/stopvdr ] ; then
      rm /var/lock/stopvdr
      exit 1
   fi
done
